@@ -15,7 +15,7 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 #                                                                # 
-# last changed in version = '2.4-1'                              #
+# last changed in version = '2.4-2'                              #
 #                                                                # 
 ##################################################################
 
@@ -133,9 +133,9 @@ if  [ "$1" == 'walsh' ]; then
 fi 
 
 if  [ "$1" == 'copyReaver' ]; then 
-    cp -pr $2/reaver $3 && chmod 755 $3/reaver 
+    cp -pr $2/reaver $3 && chmod 755 $3/reaver && ln -s $3/reaver /usr/bin/reaver
 fi 
 
 if  [ "$1" == 'copyWalsh' ]; then 
-    cp -pr $2/walsh $3 && chmod 755 $3/walsh
+    cp -pr $2/walsh $3 && chmod 755 $3/walsh && ln -s $3/walsh /usr/bin/walsh
     fi 
